@@ -6,6 +6,7 @@ from itertools import chain
 from typing import List, Union
 
 import overpy
+from overpy import Result
 from tqdm.auto import tqdm
 
 from pyridy.osm.utils import QueryResult, OSMLevelCrossing, OSMRailwaySwitch, OSMRailwaySignal, OSMRailwayLine, \
@@ -118,30 +119,33 @@ class OSMRegion:
                 self.query_results[railway_type]["route_query"] = rou_result
 
                 # Convert relation result to OSMRailwayLine objects
-                for rel in rou_result.result.relations:
-                    rel_way_ids = [mem.ref for mem in rel.members if type(mem) == overpy.RelationWay and not mem.role]
-                    rel_ways = [w for w in rou_result.result.ways if w.id in rel_way_ids]
+                if rou_result.result:
+                    for rel in rou_result.result.relations:
+                        rel_way_ids = [mem.ref for mem in rel.members if type(mem) == overpy.RelationWay and not mem.role]
+                        rel_ways = [w for w in rou_result.result.ways if w.id in rel_way_ids]
 
-                    sort_order = {id: idx for id, idx in zip(rel_way_ids, range(len(rel_way_ids)))}
-                    rel_ways.sort(key=lambda w: sort_order[w.id])
+                        sort_order = {id: idx for id, idx in zip(rel_way_ids, range(len(rel_way_ids)))}
+                        rel_ways.sort(key=lambda w: sort_order[w.id])
 
-                    self.railway_lines.append(OSMRailwayLine(rel.id, rel_ways, rel.tags, rel.members))
+                        self.railway_lines.append(OSMRailwayLine(rel.id, rel_ways, rel.tags, rel.members))
 
-                for n in trk_result.result.nodes:
-                    if "railway" in n.tags:
-                        if n.tags["railway"] == "level_crossing":
-                            self.railway_elements.append(OSMLevelCrossing(n))
-                        elif n.tags["railway"] == "signal":
-                            self.railway_elements.append(OSMRailwaySignal(n))
-                        elif n.tags["railway"] == "switch":
-                            self.railway_elements.append(OSMRailwaySwitch(n))
-                        else:
-                            pass
+                if trk_result.result:
+                    for n in trk_result.result.nodes:
+                        if "railway" in n.tags:
+                            if n.tags["railway"] == "level_crossing":
+                                self.railway_elements.append(OSMLevelCrossing(n))
+                            elif n.tags["railway"] == "signal":
+                                self.railway_elements.append(OSMRailwaySignal(n))
+                            elif n.tags["railway"] == "switch":
+                                self.railway_elements.append(OSMRailwaySwitch(n))
+                            else:
+                                pass
         else:
             logger.warning("Cant download OSM data because of not internet connection")
 
-    def query_overpass(self, query: str, attempts: int = 3):
+    def query_overpass(self, query: str, attempts: int = 3) -> Result:
         for a in range(attempts):
+            time.sleep(a)
             try:
                 logger.info("Trying to query OSM data, %d/%d tries" % (a, attempts))
                 result = self.overpass_api.query(query)
@@ -149,18 +153,16 @@ class OSMRegion:
                 return result
             except overpy.exception.OverpassTooManyRequests as e:
                 logger.warning("OverpassTooManyRequest, retrying".format(e))
-                time.sleep(1)
             except overpy.exception.OverpassGatewayTimeout as e:
                 logger.warning("OverpassTooManyRequest, retrying".format(e))
-                time.sleep(1)
             except overpy.exception.OverpassBadRequest as e:
                 logger.warning("OverpassTooManyRequest, retrying".format(e))
-                time.sleep(1)
             except socket.timeout as e:
                 logger.warning("Socket timeout, retrying".format(e))
 
         logger.info("Using alternative Overpass API url")
         for a in range(attempts):
+            time.sleep(a)
             try:
                 logger.info("Trying to query OSM data, %d/%d tries" % (a, attempts))
                 result = self.overpass_api_alt.query(query)
@@ -168,17 +170,16 @@ class OSMRegion:
                 return result
             except overpy.exception.OverpassTooManyRequests as e:
                 logger.warning("OverpassTooManyRequest, retrying".format(e))
-                time.sleep(1)
             except overpy.exception.OverpassGatewayTimeout as e:
                 logger.warning("OverpassTooManyRequest, retrying".format(e))
-                time.sleep(1)
             except overpy.exception.OverpassBadRequest as e:
                 logger.warning("OverpassTooManyRequest, retrying".format(e))
-                time.sleep(1)
             except socket.timeout as e:
                 logger.warning("Socket timeout, retrying".format(e))
         else:
-            raise RuntimeError("Could download OSM data via Overpass after %d attempts." % attempts)
+            logger.warning("Could download OSM data via Overpass after %d attempts with query: %s" % (attempts,
+                                                                                                            query))
+            return None
 
     def get_all_route_nodes(self) -> list:
         nodes = []
